#
# spec file for package libkscreen2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without released
%define sover   8
%define lname   libKF5Screen%{sover}
Name:           libkscreen2
Version:        5.27.11
Release:        1.2
# Full Plasma 5 version (e.g. 5.8.95)
%{!?_plasma5_bugfix: %define _plasma5_bugfix %{version}}
# Latest ABI-stable Plasma (e.g. 5.8 in KF5, but 5.8.95 in KUF)
%{!?_plasma5_version: %define _plasma5_version %(echo %{_plasma5_bugfix} | awk -F. '{print $1"."$2}')}
Summary:        KDE's screen management library
License:        GPL-2.0-or-later
Group:          System/GUI/KDE
URL:            http://www.kde.org
Source:         https://download.kde.org/stable/plasma/%{version}/libkscreen-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/plasma/%{version}/libkscreen-%{version}.tar.xz.sig
Source2:        plasma.keyring
%endif
BuildRequires:  cmake >= 3.16
BuildRequires:  extra-cmake-modules >= 5.98.0
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
BuildRequires:  libqt5-qtbase-private-headers-devel
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5Wayland)
BuildRequires:  cmake(PlasmaWaylandProtocols)
BuildRequires:  cmake(Qt5Core) >= 5.15.0
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5Gui)
BuildRequires:  cmake(Qt5LinguistTools)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5WaylandClient)
BuildRequires:  cmake(Qt5X11Extras)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-randr)

%description
Dynamic display management library for KDE

%package -n libKF5ScreenDpms%{sover}
Summary:        KDE's screen management library
Group:          System/GUI/KDE
Requires:       %{lname} = %{version}

%description -n libKF5ScreenDpms%{sover}
Energy saving display management library for KDE

%package plugin
Summary:        KDE's screen management library
Group:          System/GUI/KDE
Requires:       %{lname} = %{version}
Requires:       libKF5ScreenDpms%{sover} = %{version}
# Existed in KDE:Unstable:Frameworks for a short time
Provides:       %{name}-zsh-completion = %{version}
Obsoletes:      %{name}-zsh-completion < %{version}

%description plugin
Plugins for dynamic display management in KDE

%package devel
Summary:        KDE's screen management library (development package)
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Requires:       libKF5ScreenDpms%{sover} = %{version}
Requires:       cmake(Qt5Core)

%description devel
Development files belonging to libkscreen, dynamic display management in KDE

%package -n %{lname}
Summary:        KDE's screen management library
Group:          System/GUI/KDE
Recommends:     %{name}-plugin
Recommends:     libKF5ScreenDpms%{sover}

%description -n %{lname}
Shared library for dynamic display management in KDE

%lang_package -n %{lname}

%prep
%autosetup -p1 -n libkscreen-%{version}

%build
  %cmake_kf5 -d build
  %cmake_build

%install
  %kf5_makeinstall -C build
  %find_lang libkscreen5 --with-qt --all-name --without-mo
  %fdupes %{buildroot}

%post -n %{lname} -p /sbin/ldconfig
%post -n libKF5ScreenDpms%{sover} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig
%postun -n libKF5ScreenDpms%{sover} -p /sbin/ldconfig

%post plugin
%{systemd_user_post plasma-kscreen.service}

%preun plugin
%{systemd_user_preun plasma-kscreen.service}

%postun plugin
%{systemd_user_postun plasma-kscreen.service}

%files plugin
%license LICENSES/*
%{_kf5_bindir}/kscreen-doctor
%{_kf5_plugindir}/
%{_kf5_libexecdir}/
%{_kf5_sharedir}/dbus-1/services/org.kde.kscreen.service
%{_kf5_debugdir}/libkscreen.categories
%{_userunitdir}/plasma-kscreen.service
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_kscreen-doctor

%files -n %{lname}
%license LICENSES/*
%{_kf5_libdir}/libKF5Screen.so.%{sover}
%{_kf5_libdir}/libKF5Screen.so.*

%files -n libKF5ScreenDpms%{sover}
%{_kf5_libdir}/libKF5ScreenDpms.so.%{sover}
%{_kf5_libdir}/libKF5ScreenDpms.so.*

%files -n %{lname}-lang -f libkscreen5.lang

%files devel
%license LICENSES/*
%{_kf5_libdir}/libKF5Screen.so
%{_kf5_libdir}/libKF5ScreenDpms.so
%{_kf5_libdir}/cmake/KF5Screen/
%{_kf5_libdir}/pkgconfig/kscreen2.pc
%{_kf5_includedir}/
%{_kf5_mkspecsdir}/qt_KScreen.pri

%changelog
* Wed Mar  6 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.11:
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.11
- No code changes since 5.27.10
* Wed Dec  6 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.10
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.10
- Changes since 5.27.9:
  * Adjust to KWayland moving to Plasma
* Tue Oct 24 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.9
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.9
- No code changes since 5.27.8
* Tue Sep 12 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.8
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.8
- Changes since 5.27.7:
  * backends/xrandr: make sure `XRandRCrtc::update` is always called
* Tue Aug  1 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.7
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.7
- Changes since 5.27.6:
  * make sure kscreen-doctor exits when using --dpms
  * Guard the deprecated Output::setPrimary (kde#471195)
* Tue Jun 20 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.6
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.6
- Changes since 5.27.5:
  * dpms: Don't crash if trying to interact with the fake screen (kde#470484)
  * Fix the wrong argument in usage example
  * XRandR: Avoid a null pointer dereference in crtcChanged()
* Tue May  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.5
- Changes since 5.27.4:
  * xrandr: always try to update primary
  * Cleanup dpms object in destructor
  * Update edid when plugging a monitor
* Tue Apr  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.4
- No code changes since 5.27.3
* Tue Mar 14 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.3
- Changes since 5.27.2:
  * libdpms/wayland: Do not create dpms interfaces for placeholder QScreens (kde#466674)
  * dpms/xcb: Make sure we are setting it as unsupported when it is (kde#466181)
  * backends/wayland: Round passed scale
* Tue Feb 28 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.2
- Changes since 5.27.1:
  * Revert "fix(randr): screen is dirty when switching display modes" (kde#462725)
  * dpms/wayland: properly manage org_kde_kwin_dpms instances
  * dpms/wayland: Explicitly set as unsupported if addRegistryListener didn't find the interface (kde#466181)
* Tue Feb 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.1
- Changes since 5.27.0:
  * Fix potential crash setting new configs (kde#464590)
* Thu Feb  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.27.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.27.0
- No code changes since 5.26.90
* Thu Jan 19 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.90
- Too many changes to list here
* Wed Jan  4 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.5
- Changes since 5.26.4:
  * backends/kwayland: use the connector name
* Tue Nov 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.4
- No code changes since 5.26.3
* Tue Nov  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.3
- No code changes since 5.26.2
* Wed Oct 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.2
- Changes since 5.26.1:
  * Make error messages translatable
- Use %%autosetup
- Use %%fdupes with hardlinks
* Tue Oct 18 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.1
- Changes since 5.26.0:
  * backends/kwayland: only consider enabled outputs for Xwayland scale
* Thu Oct  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.26.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.26.0
- No code changes since 5.25.90
* Thu Sep 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.90
- Changes since 5.25.5:
  * Update default on XwaylandClientsScale to true
  * Add FreeBSD Qt6 CI support
  * Add missing license file
  * Fix Qt major version in CMake config files
  * Disable KF5::WaylandServer based tests for Qt6 build
  * Remove duplicate headers between cpp/h
  * wayland: Set kwin up for allowing Xwayland clients scale themselves
  * fix(randr): screen is dirty when switching display modes
  * Remove CI dependency on kwayland-server as that is no longer a thing.
* Tue Sep  6 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.5
- No code changes since 5.25.4
* Tue Aug  2 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.4
- No code changes since 5.25.3
* Tue Jul 12 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.3
- No code changes since 5.25.2
* Tue Jun 28 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.2
- No code changes since 5.25.1
* Tue Jun 21 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.1
- No code changes since 5.25.0
* Thu Jun  9 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.25.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.25.0
- Changes since 5.24.90:
  * Remove CI dependency on kwayland-server as that is no longer a thing.
* Thu May 19 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.90
- Changes since 5.24.5:
  * Use const'ref
  * Delete proxy for PrimaryOutput wayland interface in destructor (kde#451847)
  * Adapt recent DPMS changes to also build with Qt6
  * [doctor] Port dpms handling to QtWaylandScanner
  * Adapt build system to also support Qt6
  * backends/kwayland: Use output name to guess output type
  * Update required PlasmaWaylandProtocols version
* Tue May  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.5
- No code changes since 5.24.4
* Tue Mar 29 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.4
- No code changes since 5.24.3
* Tue Mar  8 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.3
- No code changes since 5.24.2
* Tue Feb 22 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.2
- No code changes since 5.24.1
* Tue Feb 15 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.1
- No code changes since 5.24.0
* Sat Feb  5 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.24.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.24.0
- Changes since 5.23.90:
  * backends/kwayland: Use output name to guess output type
  * Update required PlasmaWaylandProtocols version
* Thu Jan 13 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.90
- Changes since 5.23.5:
  * GetConfiguration: ensure to set explicitLogicalSize for returned outputs
  * Add KScreen::Config::Feature::SynchronousOutputChanges
  * Wayland: Wait for KWin reply before returning from setConfig
  * Fix some clazy warnings
  * Under X11 ignore per-screen scale to compute logicalSize
  * Enable GitLab CI
  * Add KScreen::Output::typeName
  * wayland: Issue a configChanged when the primary changes
  * Do not issue SetConfigOperations with bogus primary states
  * Fix using correct log level by using systemd unit (kde#444084)
  * wayland: Properly choose interface versions
  * Implement Primary Displays on the wayland session
  * Add support to primary into the kscreen-doctor tool
  * XrandR: Fix impossibilty to change resolution in VirtualBox (kde#407058)
  * Fix autorotate when "only in tablet mode" is selected (kde#428626)
  * Add .kde-ci.yml
  * fix all the new settings (kde#442520)
* Tue Jan  4 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.5
- No code changes since 5.23.4
* Tue Nov 30 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.4
- No code changes since 5.23.3
* Tue Nov  9 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.3
- No code changes since 5.23.2
* Tue Oct 26 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.2
- No code changes since 5.23.1
* Tue Oct 19 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.1
- No code changes since 5.23.0
* Mon Oct 11 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.23.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.23.0
- Changes since 5.22.90:
  * Fix autorotate when "only in tablet mode" is selected (kde#428626)
  * fix all the new settings (kde#442520)
- Add new key + signature to plasma.keyring
* Thu Sep 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.90
- Changes since 5.22.5:
  * wayland: Fix output hotplugging
  * wayland: Fix output transforms
  * add rgb range setting
  * Add support for plasma wayland protocol kde_output_device_v2
  * Explicitly set KDE_COMPILERSETTINGS_LEVEL
  * Natural sort the outputs modes in kscreen-doctor
  * Use qEnvironmentVariable() with a default instead of qgetenv()
  * dpms: Remove boilerplatey code
  * dpms: Do not hardcode the wayland socket
  * Update IRC network name in CONTRIBUTING.md
  * Use version-less qt DBus macros
  * We depend against 5.82
  * Use the same wayland connection to fetch screen information
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Tue Aug 31 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.5
- No code changes since 5.22.4
* Tue Jul 27 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.4
- No code changes since 5.22.3
* Tue Jul  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.3
- No code changes since 5.22.2.1
* Wed Jun 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.2.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.2
- No code changes since 5.22.1
* Tue Jun 15 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.1
- No code changes since 5.22.0
* Thu Jun  3 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.22.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.22.0
- Changes since 5.21.90:
  * Use the same wayland connection to fetch screen information
* Thu May 13 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.90
- Changes since 5.21.5:
  * Migrate to KDECompilerSettings
  * Port away from ECMSetupVersion's deprecated *_VERSION_STRING CMake variable
  * Add VRR properties
  * Add overscan and capabilities properties
  * Port Away from Qt Keywords
  * Raise minimum CMake version to 3.16
  * Convert license headers to SPDX
  * Remove unneeded include_directories
  * Update CONTRIBUTING.md
  * Remove manual symbol visibility handling
  * Remove weird variable assignment
  * Remove superflous ECM_KDE_MODULE_DIR
  * Use versionless Qt cmake target
  * Fix refresh rate reported for my laptop monitor
  * wayland: Fix mapping between kscreen and kwayland transforms
  * Add pre-commit hook for clang-format
* Tue May  4 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.5
- No code changes since 5.21.4
* Tue Apr  6 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.4
- No code changes since 5.21.3
* Tue Mar 16 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.3
- No code changes since 5.21.2
* Tue Mar  2 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.2
- No code changes since 5.21.1
* Tue Feb 23 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.1
- No code changes since 5.21.0
* Thu Feb 11 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.21.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/5.21.0
- Changes since 5.20.90:
  * Fix refresh rate reported for my laptop monitor
  * wayland: Fix mapping between kscreen and kwayland transforms
* Thu Jan 21 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/plasma/5/20.90/
- Changes since 5.20.5:
  * Update .gitignore file
  * Add .git-blame-ignore-revs file
  * clang-tidy: Force braces around statements
  * Run clang-format
  * Add missing protect header
  * Fix build with newer Qt
  * doctor: Add an option to allow excluding outputs from a dpms action
  * Fix build with newer Qt
  * ConfigMonitor: Properly combine erase and iteration
  * Proper variable scope
  * KScreen::Output debug output readability
  * Config: Reserve hash size before populating it
  * edid: Do not split strings twice unnecessarily
  * edid: Do not access unallocated QByteArrays
  * wayland: Provide the Edid when we have it
  * Prefer straightforward API
  * wayland: remove meaningless comment
  * doctor: do not crash when accessing dpms
  * Initialise the WaylandOutput::size
  * Use non-deprecated scale method to calculate the screen geometry
  * Remove unused method declaration
  * Include rotation in the debug output
  * Remove not implemented method
  * Use new simpler way to disable session management
* Tue Jan  5 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.5
- No code changes since 5.20.4
* Tue Dec  1 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.4
- Changes since 5.20.3:
  * Fix build with newer Qt
* Wed Nov 11 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.3
- No code changes since 5.20.2
* Tue Oct 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.2
- No code changes since 5.20.1
* Tue Oct 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.1
- No code changes since 5.20.0
* Thu Oct  8 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.20.0
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.20.0
- No code changes since 5.19.90
* Thu Sep 17 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.90
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.90
- Changes since 5.19.5:
  * Require C++17
  * fix: Fix wrong includes being picked up
* Tue Sep  1 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.5
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.5
- No code changes since 5.19.4
* Tue Jul 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.4
- No code changes since 5.19.3
* Tue Jul  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.3
- No code changes since 5.19.2
* Tue Jun 23 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/plasma-5.19.2
- No code changes since 5.19.1
* Tue Jun 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.19.1.php
- No code changes since 5.19.0
* Thu Jun  4 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.19.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.19.0.php
- No code changes since 5.18.90
* Thu May 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.90.php
- Changes since 5.18.5:
  * bump to require Qt 5.14
  * build: ignore clang-format file
  * docs: update commit message guideline version
  * fix: transfer tablet mode properties (kde#418739)
  * fix: consider DSI display to be embedded panel
  * feat(kwayland): enable the auto-rotation and tablet mode
  * fix: handle when backend fails to load/initialize
  * test: query correct output
  * fix: reset doctor output color before exiting
* Tue May  5 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.5.php
- No code changes since 5.18.4.1
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4.1:
  * Version fixed
* Tue Mar 31 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.4.php
- No code changes since 5.18.3
* Tue Mar 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.3.php
- Changes since 5.18.2:
  * fix: handle when backend fails to load/initialize
* Tue Feb 25 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.2.php
- Changes since 5.18.1:
  * fix: handle when backend fails to load/initialize
  * fix(kwayland): wait longer for connection timeout and retry (kde#416566)
  * fix(kwayland): remove code with side-effects from Q_ASSERT (kde#413892)
* Tue Feb 18 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.1.php
- No code changes since 5.18.0
* Thu Feb  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.18.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.18.0.php
- No code changes since 5.17.90
* Thu Jan 23 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build
* Mon Jan 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Fix version in source URL
* Thu Jan 16 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.90.1
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.90.php
- Changes since 5.17.5:
  * fix(kwayland): move blocking tablet init before timer start
  * KF5_MIN_VERSION for plasma 5.18 is KF5 5.66.0
  * fix(randr): make sure crtc exists
  * feat: add auto rotate and tablet mode information
  * feat: replace replication source with logical size API
  * docs: add todos for KF6
  * docs: add contributing guide
  * Add KDEClangFormat cmake support
  * [wayland] Don't init m_internalConfig twice
  * Now we depend against kf5.58
  * Make it compile against qt 5.14
* Tue Jan  7 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.5.php
- No code changes since 5.17.4
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.4.php
- No code changes since 5.17.3
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.3.php
- No code changes since 5.17.2
* Tue Oct 29 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.2.php
- No code changes since 5.17.1
* Tue Oct 22 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.1.php
- No code changes since 5.17.0
* Thu Oct 10 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.17.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.17.0.php
- No code changes since 5.16.90
* Thu Sep 19 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.90.php
- Changes since 5.16.5:
  * update to latest kf5 dependency
  * Add enforced mode size getter
  * RandR: Replicate outputs with XRender extension
  * Introduce output replication API
  * Wayland: Set fractional output scale
  * XRandR: Generic code cleanup
  * Wayland: Rename output member variable
  * Wayland: Improve screen code style
  * Wayland: set KWayland outputs data in output class
  * Wayland: unfriend config and output classes
  * Wayland: output device name as create function argument only
  * Wayland: save pointers in initializing list
  * Simplify XRandR::outputChanged
  * Wayland: manage outputs without id mapping
  * Wayland: config update code cleanup
  * Wayland: backend code cleanup
  * Do hash and hex name based output hashes
  * Install in new logging directory when we use kf5 5.59.0
  * Fix forward declaration
* Tue Sep  3 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.5.php
- No code changes since 5.16.4
* Tue Jul 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.16.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.4.php
- No code changes since 5.16.3
* Tue Jul  9 2019 fabian@ritter-vogt.de
- Update to 5.16.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.3.php
- No code changes since 5.16.2
* Tue Jun 25 2019 fabian@ritter-vogt.de
- Update to 5.16.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.2.php
- No code changes since 5.16.1
* Tue Jun 18 2019 fabian@ritter-vogt.de
- Update to 5.16.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.1.php
- No code changes since 5.16.0
* Thu Jun  6 2019 fabian@ritter-vogt.de
- Update to 5.16.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.16.0.php
- No code changes since 5.15.90
* Thu May 16 2019 fabian@ritter-vogt.de
- Update to 5.15.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.90.php
- Changes since 5.15.5:
  * bump Qt version to 5.12 as agreed at start of cycle
* Tue May  7 2019 fabian@ritter-vogt.de
- Update to 5.15.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.5.php
- No code changes since 5.15.4
* Tue Apr  2 2019 fabian@ritter-vogt.de
- Update to 5.15.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.4.php
- No code changes since 5.15.3
* Tue Mar 12 2019 fabian@ritter-vogt.de
- Update to 5.15.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.3.php
- No code changes since 5.15.2
* Tue Feb 26 2019 fabian@ritter-vogt.de
- Update to 5.15.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.2.php
- No code changes since 5.15.1
* Tue Feb 19 2019 fabian@ritter-vogt.de
- Update to 5.15.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.1.php
- Changes since 5.15.0:
  * Exclude kscreen backend launcher from session management
* Thu Feb  7 2019 fabian@ritter-vogt.de
- Update to 5.15.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.15.0.php
- Changes since 5.14.90:
  * Guard failing to load backend (kde#403568)
* Thu Jan 17 2019 fabian@ritter-vogt.de
- Update to 5.14.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.90.php
- Changes since 5.14.5:
  * bump KF5 dependency to required 5.54 as agreed at start of Plasma 5.15 cycle
  * Consti'fy
  * Fix some clazy warning
  * USe KF5_MIN_VERSION
  * Notify also if modes have changed
  * Define ownership of edid in output and do not leak it
  * Add output and connected outputs config API
  * Move categories here
  * Rename kscreen.categories to libkscreen.categories
  * Autogenerate debug categories + create categories file
  * Avoid creation of needless temporary containers
  * Remove unused QPointer includes
  * Don't leak Edid
  * Fix qstring-insensitive-allocation clazy warning
  * Remove unused member variable
  * Support QXL hotplug_mode_update
  * Use KDEFrameworkCompilerSettings
* Tue Jan  8 2019 fabian@ritter-vogt.de
- Update to 5.14.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.5.php
- Changes since 5.14.4:
  * Notify also if modes have changed
* Wed Nov 28 2018 fabian@ritter-vogt.de
- Update to 5.14.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.4.php
- No code changes since 5.14.3
* Tue Nov  6 2018 fabian@ritter-vogt.de
- Add David Edmundson's key to plasma.keyring
- Update to 5.14.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.3.php
- No code changes since 5.14.2
* Tue Oct 23 2018 fabian@ritter-vogt.de
- Update to 5.14.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.2.php
- No code changes since 5.14.1
* Tue Oct 16 2018 fabian@ritter-vogt.de
- Update to 5.14.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.1.php
- No code changes since 5.14.0
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.14.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.14.0.php
- No code changes since 5.13.90
* Sat Sep 15 2018 fabian@ritter-vogt.de
- Add tarball signature and keyring containing keys of release managers
  Jonathan Riddell and Bhushan Shah
* Thu Sep 13 2018 fabian@ritter-vogt.de
- Update to 5.13.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.90.php
- Too many changes to list here
* Tue Sep  4 2018 fabian@ritter-vogt.de
- Update to 5.13.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.5.php
- Changes since 5.13.4:
  * None
* Tue Jul 31 2018 fabian@ritter-vogt.de
- Update to 5.13.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.4.php
- Changes since 5.13.3:
  * Make TestInProcess skip out-of-process tests if D-Bus service uninstalled
* Tue Jul 10 2018 fabian@ritter-vogt.de
- Update to 5.13.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.3.php
- Changes since 5.13.2:
  * Fix uninstalled run unit tests: set LIBRARY_OUTPUT_DIRECTORY for plugins
* Tue Jun 26 2018 fabian@ritter-vogt.de
- Update to 5.13.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.2.php
- Changes since 5.13.1:
  * None
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.13.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.1.php
- Changes since 5.13.0:
  * None
* Thu Jun  7 2018 fabian@ritter-vogt.de
- Update to 5.13.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.13.0.php
- Changes since 5.12.90:
  * None
* Sat May 19 2018 fabian@ritter-vogt.de
- Update to 5.12.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.90.php
- Changes since 5.12.5:
  * XRandR: Fix 'may fall through' warning
  * Fix kscreen-doctor description
  * [kscreen-doctor] document output scaling in --help
  * allow setting rotation from kscreen-doctor
  * Do not leak symbols of pimpl classes, protect with Q_DECL_HIDDEN
  * Add option for creation of API dox documentation in QCH format
  * Remove outdated & broken option for API dox creation
  * Use generated export header
  * Update D-Bus xml file to use "Out*" for signal type Qt annotations
  * Use KF5_MIN_VERSION also for ECM, now that it's part of KF
  * Use non-deprecated KDEInstallDirs variables
  * Remove module namespace from Qt includes
  * Drop ECMPackageConfigHelpers for CMakePackageConfigHelpers
  * Bump min cmake version to 3.0
  * Build test/autotest if BUILD_TESTING is defined
* Wed May  2 2018 fabian@ritter-vogt.de
- Update to 5.12.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.5.php
- Changes since 5.12.4:
  * None
* Tue Mar 27 2018 fabian@ritter-vogt.de
- Update to 5.12.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.4.php
- Changes since 5.12.3:
  * None
* Tue Mar  6 2018 fabian@ritter-vogt.de
- Update to 5.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.3.php
- Changes since 5.12.2:
  * None
* Wed Feb 21 2018 lbeltrame@kde.org
- Update to 5.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.2.php
- Changes since 5.12.1:
  * None
* Tue Feb 13 2018 fabian@ritter-vogt.de
- Update to 5.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.1.php
- Changes since 5.12.0:
  * Fix missing Qt5::Gui in public link interface, pulled in by QQuaternion
  * Require KDE Frameworks 5.42 and Qt 5.9
* Fri Feb  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.12.0.php
- Changes since 5.11.95:
  * Fix tests after recent changes
  * Wayland: add support for output type detection
  * Wayland: don't update output configuration if there are no changes
  * Don't create multiple in-process backend instances
  * Wayland: don't share the same Config between backend and clients
* Mon Jan 15 2018 fabian@ritter-vogt.de
- Update to 5.11.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.95.php
- Changes since 5.11.5:
  * Remove obsolete reviewboardrc file
  * Fix typo
  * Honour the preferred mode flag in the kwayland backend
  * kwaylandconfig: autotest scale changed signal arrival
  * add scale and labels to output debug
  * add debug << operator to config
  * show in debug what the result is supposed to be
  * Use nullptr. Initialize pointer
  * Allow setting mode by widthxheight@refreshrate
  * Also copy scale in Output::apply()
  * Merge scale changes
  * let's continue in debug code instead of returning from XRandRConfig::applyKScreenConfig
  * Add setScale option to kscreendoctor
  * Use QString for number parsing
  * fix comment
  * kscreen-doctor: support setting scale of outputs
  * Test only changing the scale
* Tue Jan  2 2018 fabian@ritter-vogt.de
- Update to 5.11.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.5.php
- Changes since 5.11.4:
  * Fix Config supportedFeatures not being passed between backend and clients
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.11.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.4.php
- Changes since 5.11.3:
  * XRandR: Clear EDID data when monitor is disconnected from an output
* Tue Nov  7 2017 fabian@ritter-vogt.de
- Update to 5.11.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.3.php
- Changes since 5.11.2:
  * None
* Tue Oct 24 2017 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.2.php
- Changes since 5.11.1:
  * None
* Tue Oct 17 2017 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.1.php
- Changes since 5.11.0:
  * None
* Thu Oct  5 2017 fabian@ritter-vogt.de
- Update to 5.11.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.11.0.php
- Changes since 5.10.95:
  * None
* Thu Sep 14 2017 fabian@ritter-vogt.de
- Update to 5.10.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.95.php
- Changes since 5.10.5:
  * When cloning a config also clone supportedFeatures
  * warnings--;
  * let's continue in debug code instead of returning from XRandRConfig::applyKScreenConfig
  * Add setScale option to kscreendoctor
  * USe Q_DECL_OVERRIDE
  * Delete registry before connection
  * Update unit test to match scaling
* Tue Aug 22 2017 fabian@ritter-vogt.de
- Update to 5.10.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.5.php
- Changes since 5.10.4:
  * None
* Tue Jul 18 2017 fabian@ritter-vogt.de
- Update to 5.10.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.4.php
- Changes since 5.10.3:
  * None
* Tue Jun 27 2017 fabian@ritter-vogt.de
- Update to 5.10.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.3.php
- Changes since 5.10.2:
  * None
* Tue Jun 13 2017 fabian@ritter-vogt.de
- Update to 5.10.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.2.php
- Changes since 5.10.1:
  * let's continue in debug code instead of returning from XRandRConfig::applyKScreenConfig
* Tue Jun  6 2017 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.1.php
- Changes since 5.10.0:
  * Add setScale option to kscreendoctor
* Fri May 26 2017 fabian@ritter-vogt.de
- Update to 5.10.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.10.0.php
- Changes since 5.9.95:
  * None
* Thu May 11 2017 fabian@ritter-vogt.de
- Update to 5.9.95
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.95.php
- Changes since 5.9.5:
  * Sync scale to/from KScreen configs
  * Sync kscreen outputs to wayland
  * Fix compile warning of treating boolean like an integer
  * Fix Output::geometry() when dealing with a scaled monitor
  * Sync wayland output scale to KScreen config
  * Fix type argument for get property call
* Tue Apr 25 2017 lbeltrame@kde.org
- Update to 5.9.5
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.5.php
- Changes since 5.9.4:
  * None
* Tue Mar 21 2017 fabian@ritter-vogt.de
- Update to 5.9.4
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.4.php
- Changes since 5.9.3:
  * None
* Tue Feb 28 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.3.php
- Changes since 5.9.2:
  * None
* Tue Feb 14 2017 fabian@ritter-vogt.de
- Update to 5.9.2
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.2.php
- Changes since 5.9.1:
  * None
* Tue Feb  7 2017 fabian@ritter-vogt.de
- Update to 5.9.1
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.1.php
- Changes since 5.9.0:
  * Fix type argument for get property call
  * disable logging to kscreen.log by default
  * allow changing an output's modelist at runtime
* Thu Jan 26 2017 fabian@ritter-vogt.de
- Update to 5.9.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/plasma-5.9.0.php
- Changes since 5.8.95:
  * Fix type argument for get property call
* Thu Jan 12 2017 fabian@ritter-vogt.de
- Update to 5.8.95 (Plasma 5.9 Beta)
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.95.php
- Changes:
  * Disable logging to kscreen.log by default.
  * Scale property for KScreen::Output.
  * Allow changing an output's modelist at runtime. Fixes kde#356864
  * Handle integer display types from config in fake backend.
  * Include refresh rate in mode's debug handler.
  * Add flag to for per-display scaling.
* Tue Dec 27 2016 fabian@ritter-vogt.de
- Update to 5.8.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.5.php
* Wed Nov 23 2016 fabian@ritter-vogt.de
- Update to 5.8.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.4.php
* Thu Nov  3 2016 fabian@ritter-vogt.de
- Introduce new _plasma5_bugfix global for more fine-tuned dependencies
* Tue Nov  1 2016 fabian@ritter-vogt.de
- Update to 5.8.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.3.php
* Tue Oct 18 2016 fabian@ritter-vogt.de
- Update to 5.8.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.2.php
* Tue Oct 11 2016 fabian@ritter-vogt.de
- Update to 5.8.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.1.php
* Wed Oct  5 2016 fabian@ritter-vogt.de
- Add Source: URL back
* Thu Sep 29 2016 fabian@ritter-vogt.de
- Update to 5.8.0
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.8.0.php
* Wed Sep 21 2016 fabian@ritter-vogt.de
- Use %%{_plasma5_version} again, define it if needed
* Thu Sep 15 2016 fabian@ritter-vogt.de
- Update to 5.7.95 (Plasma 5.8 Beta)
  * New LTS feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.95.php
* Tue Sep 13 2016 fabian@ritter-vogt.de
- Update to 5.7.5
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.5.php
* Fri Aug 26 2016 fabian@ritter-vogt.de
- Update to 5.7.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.4.php
* Tue Aug  2 2016 hrvoje.senjan@gmail.com
- Update to 5.7.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.3.php
* Wed Jul 20 2016 hrvoje.senjan@gmail.com
- Update to 5.7.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.2.php
* Wed Jul 13 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.1.php
* Thu Jun 30 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.7.0.php
* Sun May 15 2016 hrvoje.senjan@gmail.com
- Update to 5.6.4
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.4.php
* Tue Apr 19 2016 hrvoje.senjan@gmail.com
- Update to 5.6.3
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.3.php
* Tue Apr  5 2016 hrvoje.senjan@gmail.com
- Update to 5.6.2
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.2.php
* Tue Mar 29 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * New bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.1.php
* Sun Mar 20 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.6.0.php
* Tue Mar  1 2016 hrvoje.senjan@gmail.com
- Update to 5.5.5 (boo#968966)
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.5.php
* Tue Jan 26 2016 hrvoje.senjan@gmail.com
- Update to 5.5.4:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.4.php
* Wed Jan  6 2016 hrvoje.senjan@gmail.com
- Update to 5.5.3:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.3.php
* Tue Dec 22 2015 hrvoje.senjan@gmail.com
- Update to 5.5.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.2.php
* Tue Dec 15 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.5.1.php
* Sat Dec 12 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0:
  * For more details please see:
    https://dot.kde.org/2015/12/08/plasma-55-beautiful-new-artwork
- Move to cmake(...) BuildRequires where possible
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.4.3 (boo#955068):
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.3.php
* Sun Oct  4 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.2.php
* Thu Sep 10 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.1.php
* Mon Aug 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.0:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.4.0.php
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.3.95 aka 5.4 beta:
  This release of Plasma brings many nice touches for our users
  such as much improved high DPI support, KRunner auto-completion
  and many new beautiful Breeze icons. It also lays the ground for
  the future with a tech preview of Wayland session available.
  We're shipping a few new components such as an Audio Volume
  Plasma Widget, monitor calibration tool and the User Manager
  tool comes out beta.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.95.php
* Sun Jun 28 2015 hrvoje.senjan@gmail.com
- Update to 5.3.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.2.php
* Fri May 22 2015 hrvoje.senjan@gmail.com
- Update to 5.3.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.1.php
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 5.3 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.3.0.php
* Sat Apr 11 2015 hrvoje.senjan@gmail.com
- Update to 5.2.95 aka 5.3 beta:
  * New feature release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.95.php
- Update required Qt version to 5.4.0
* Thu Mar 19 2015 hrvoje.senjan@gmail.com
- Update to 5.2.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.2.php
* Fri Feb 20 2015 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.1.php
- Drop 0001-Fix-crash-when-multiple-EDID-requests-for-the-same-o.patch,
  merged upstream
* Thu Jan 29 2015 hrvoje.senjan@gmail.com
- Added 0001-Fix-crash-when-multiple-EDID-requests-for-the-same-o.patch
  (kde#343482), from upstream
* Mon Jan 26 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Final:
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.2.0.php
* Tue Jan 13 2015 hrvoje.senjan@gmail.com
- Update to 5.2 Beta aka 5.1.95:
  * Undo changes to Plasma desktop layout
  * Smarter sorting of results in KRunner
  * Breeze window decoration theme adds a new look to your
    desktop and is now used by default
  * New white mouse cursor theme for Breeze.
  * New plasma widgets: 15 puzzle, web browser, show desktop
  * Over 300 bugs fixed throughout Plasma modules.
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.95.php
- Added pkgconfig(Qt5DBus) BuildRequires
- Shlib package is now libKF5Screen6
* Thu Dec 11 2014 hrvoje.senjan@gmail.com
- Update to 5.1.2:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.2.php
* Thu Nov  6 2014 hrvoje.senjan@gmail.com
- Update to 5.1.1:
  * Bugfix release
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.1.php
* Thu Oct  9 2014 hrvoje.senjan@gmail.com
- Update to 5.1 Final:
  * Bugfixes since RC1
  * For more details please see:
    https://www.kde.org/announcements/plasma-5.1.0.php
* Fri Sep 26 2014 hrvoje.senjan@gmail.com
- Update to 5.0.95:
  * Added QScreen backend
* Sun Aug 10 2014 hrvoje.senjan@gmail.com
- Update to 5.0.92:
  * Bugfix release
* Fri Jul 11 2014 hrvoje.senjan@gmail.com
- Version bump to 5.0.91:
  * libkscreen is expected to become part of KDE Frameworks
* Thu Jul  3 2014 hrvoje.senjan@gmail.com
- Update to 1.73
  * Plasma 5 RC release
* Sat Jun  7 2014 hrvoje.senjan@gmail.com
- Update to 1.72
  * No upstream changelog provided
* Tue Jun  3 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf
- Add Source URL
* Sat May 17 2014 hrvoje.senjan@gmail.com
- Activate libkscreen2 package
